/* the Music Player Daemon (MPD)
 * Copyright (C) 2003-2007 by Warren Dukes (warren.dukes@gmail.com)
 * This project's homepage is: http://www.musicpd.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MPD_BUFFER_2_ARRAY_H
#define MPD_BUFFER_2_ARRAY_H

/* tokenizes up to max elements in buffer (a null-terminated string) and
 * stores the result in array (which must be capable of holding up to
 * max elements).  Tokenization is based on C string quoting rules.
 * The arguments buffer and array are modified.
 * Returns the number of elements tokenized.
 */
int buffer2array(char *buffer, char *array[], const int max);

#endif
